django\_sorcery package
=======================

.. automodule:: django_sorcery
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   django_sorcery.db
   django_sorcery.formsets
   django_sorcery.management
   django_sorcery.validators
   django_sorcery.views
   django_sorcery.viewsets

Submodules
----------

.. toctree::
   :maxdepth: 4

   django_sorcery.exceptions
   django_sorcery.fields
   django_sorcery.forms
   django_sorcery.pytest_plugin
   django_sorcery.routers
   django_sorcery.shortcuts
   django_sorcery.testing
   django_sorcery.utils
